@@ -4,9 +4,9 @@ import argparse
 import json
 import os
 
+import eaas.endpoint
+
 from explainaboard import get_loader_class, get_processor, TaskType
-from explainaboard.analyzers import get_pairwise_performance_gap
-from explainaboard.analyzers.draw_hist import draw_bar_chart_from_reports
 from explainaboard.constants import Source
 from explainaboard.info import SysOutputInfo
 from explainaboard.loaders.file_loader import (
@@ -14,6 +14,8 @@ from explainaboard.loaders.file_loader import (
     FileLoaderField,
     FileLoaderMetadata,
 )
+from explainaboard.metrics.eaas import EaaSMetricConfig
+from explainaboard.metrics.metric import MetricConfig
 from explainaboard.metrics.registry import get_metric_config_class
 from explainaboard.utils.io_utils import text_writer
 from explainaboard.utils.logging import get_logger
@@ -23,6 +25,8 @@ from explainaboard.utils.tensor_analysis import (
     print_score_tensor,
 )
 from explainaboard.utils.typing_utils import unwrap
+from explainaboard.visualizers import get_pairwise_performance_gap
+from explainaboard.visualizers.draw_hist import draw_bar_chart_from_reports
 
 
 def get_tasks(task: TaskType, system_outputs: list[str]) -> list[TaskType]:
@@ -298,6 +302,29 @@ def create_parser():
     return parser
 
 
+def get_metric_config_or_eaas(name: str) -> type[MetricConfig]:
+    """Obtains MetricConfig class from registry or corresponding EaaS binding.
+
+    Args:
+        name: Name of the metric.
+
+    Returns:
+        A MetricConfig class associated to either a registered Metric or EaaS.
+
+    Raises:
+        ValueError: `name` is not registered in neither the registry nor EaaS.
+    """
+    try:
+        return get_metric_config_class(name)
+    except ValueError:
+        if name in eaas.endpoint.EndpointConfig().valid_metrics:
+            return EaaSMetricConfig
+
+    raise ValueError(
+        f"Metric name {name} is not registered in neither the registry nor EaaS."
+    )
+
+
 # TODO(Pengfei): The overall implementation of this script should be deduplicated
 def main():
     args = create_parser().parse_args()
@@ -429,7 +456,7 @@ def main():
             if 'metric_configs' in metadata:
                 raise ValueError('Cannot specify both metric names and metric configs')
             metric_configs = [
-                get_metric_config_class(name)(name, source_language, target_language)
+                get_metric_config_or_eaas(name)(name, source_language, target_language)
                 for name in metric_names
             ]
             metadata["metric_configs"] = metric_configs
@@ -447,18 +474,23 @@ def main():
             metadata["task_name"] = task
 
             processor = get_processor(task=task)
-            report = processor.process(metadata=metadata, sys_output=system_dataset)
+            report = processor.process(
+                metadata=metadata, sys_output=system_dataset.samples
+            )
             reports.append(report)
 
             # print to the console
             get_logger('report').info('--- Overall Performance')
-            for metric_stat in report.results.overall.values():
-                get_logger('report').info(
-                    f'{metric_stat.metric_name}\t{metric_stat.value}'
-                )
+            for overall_level in report.results.overall:
+                for metric_stat in overall_level:
+                    get_logger('report').info(
+                        f'{metric_stat.metric_name}\t{metric_stat.value}'
+                    )
             get_logger('report').info('')
-            get_logger('report').info('--- Bucketed Performance')
-            processor.print_bucket_info(report.results.fine_grained)
+            get_logger('report').info('--- Fine-grained Analyses')
+            for analysis in report.results.analyses:
+                if analysis is not None:
+                    analysis.print()
 
             if output_dir:
 
