@@ -10,6 +10,11 @@ from scipy.stats import t as stats_t
 from explainaboard.utils.typing_utils import unwrap, unwrap_or
 
 
+@dataclass
+class AuxiliaryMetricResult:
+    pass
+
+
 @dataclass
 class MetricResult:
     """
@@ -24,6 +29,8 @@ class MetricResult:
     conf_interval: Optional[tuple[float, float]] = None
     # The p-value of the confidence interval
     conf_value: Optional[float] = None
+    # Extra data for
+    auxiliary_result: AuxiliaryMetricResult | None = None
 
     def to_dict(self):
         ret = {
@@ -48,7 +55,9 @@ class MetricConfig(dict):
     name: str
     source_language: str | None = None
     target_language: str | None = None
-    cls_name: str = ''
+    cls_name: str | None = None
+    # The external statistics for metrics
+    external_stats: np.ndarray | None = None
 
     def __post_init__(self):
         # Save the class name
@@ -57,6 +66,10 @@ class MetricConfig(dict):
     def to_metric(self):
         raise NotImplementedError
 
+    @classmethod
+    def dict_conv(cls, k, v):
+        return v
+
 
 class MetricStats:
     """
