@@ -44,5 +44,5 @@ class TestAspectBasedSentimentClassification(unittest.TestCase):
 
         sys_info = processor.process(metadata, data)
 
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
