@@ -1,10 +1,12 @@
+from pathlib import Path
 import unittest
 from unittest import TestCase
 from unittest.mock import patch
 
-from explainaboard.explainaboard_main import main
-from explainaboard.tests.utils import OPTIONAL_TEST_SUITES, top_path
+import explainaboard.explainaboard_main
+from explainaboard.tests.utils import OPTIONAL_TEST_SUITES, test_output_path, top_path
 from explainaboard.utils.cache_api import cache_online_file
+import explainaboard.visualizers.draw_hist
 
 
 class TestCLI(TestCase):
@@ -24,7 +26,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_textclass_datalab_pairwise(self):
         args = [
@@ -40,7 +42,35 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
+
+    def test_textclass_viz(self):
+        Path(f"{test_output_path}/reports").mkdir(parents=True, exist_ok=True)
+        Path(f"{test_output_path}/figures").mkdir(parents=True, exist_ok=True)
+        for sysname in ('lstm', 'cnn'):
+            args = [
+                'explainaboard.explainaboard_main',
+                '--task',
+                'text-classification',
+                '--system_outputs',
+                f'{top_path}/data/system_outputs/sst2/sst2-{sysname}-output.txt',
+                '--dataset',
+                'sst2',
+                '--report_json',
+                f'{test_output_path}/reports/sst2-{sysname}-output.json',  # noqa
+            ]
+            with patch('sys.argv', args):
+                explainaboard.explainaboard_main.main()
+        args = [
+            'explainaboard.visualizers.draw_hist',
+            '--reports',
+            f'{test_output_path}/reports/sst2-lstm-output.json',
+            f'{test_output_path}/reports/sst2-cnn-output.json',
+            '--output_dir',
+            f'{test_output_path}/figures/',
+        ]
+        with patch('sys.argv', args):
+            explainaboard.visualizers.draw_hist.main()
 
     def test_textclass_custom(self):
         args = [
@@ -55,7 +85,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_tabreg_custom(self):
         args = [
@@ -70,7 +100,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_tabclass_custom(self):
         args = [
@@ -85,7 +115,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     @unittest.skipUnless('cli_all' in OPTIONAL_TEST_SUITES, reason='time consuming')
     def test_textpair_datalab(self):
@@ -101,7 +131,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_textpair_custom(self):
         args = [
@@ -116,7 +146,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_summ_custom(self):
         args = [
@@ -134,7 +164,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     @unittest.skipUnless('cli_all' in OPTIONAL_TEST_SUITES, reason='time consuming')
     def test_summ_datalab(self):
@@ -156,7 +186,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_mt_custom(self):
         args = [
@@ -173,7 +203,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_codegen_custom(self):
         args = [
@@ -192,7 +222,7 @@ class TestCLI(TestCase):
             "report.json",
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_codegen_datalab(self):
         args = [
@@ -209,7 +239,7 @@ class TestCLI(TestCase):
             "report.json",
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_lm_custom(self):
         args = [
@@ -224,7 +254,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_ner_datalab(self):
         args = [
@@ -241,7 +271,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_ner_custom(self):
         args = [
@@ -256,7 +286,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_multichoiceqa_datalab(self):
         args = [
@@ -273,7 +303,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_multichoiceqa_custom(self):
         args = [
@@ -288,7 +318,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_extractiveqa_custom(self):
         args = [
@@ -303,7 +333,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     @unittest.skip(
         reason="to be fixed in future PR: "
@@ -322,7 +352,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_kglinktail_custom(self):
         args = [
@@ -337,7 +367,7 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
 
     def test_absa_custom(self):
         args = [
@@ -352,4 +382,4 @@ class TestCLI(TestCase):
             '/dev/null',
         ]
         with patch('sys.argv', args):
-            main()
+            explainaboard.explainaboard_main.main()
