@@ -3,7 +3,7 @@ import unittest
 
 from explainaboard import FileType, get_processor, Source, TaskType
 from explainaboard.loaders.file_loader import DatalabLoaderOption
-from explainaboard.loaders.loader_registry import get_datalab_loader
+from explainaboard.loaders.loader_registry import get_loader_class
 from explainaboard.tests.utils import test_artifacts_path
 
 
@@ -12,8 +12,7 @@ class TestClozeGenerative(unittest.TestCase):
     json_output = os.path.join(artifact_path, "rst_2018_quanguojuan1_cloze_hint.json")
 
     def test_datalab_loader(self):
-        loader = get_datalab_loader(
-            TaskType.cloze_generative,
+        loader = get_loader_class(TaskType.cloze_generative).from_datalab(
             dataset=DatalabLoaderOption("gaokao2018_np1", "cloze-hint"),
             output_data=self.json_output,
             output_source=Source.local_filesystem,
@@ -29,7 +28,7 @@ class TestClozeGenerative(unittest.TestCase):
         }
         processor = get_processor(TaskType.cloze_generative.value)
         sys_info = processor.process(metadata, data)
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
 
 
 if __name__ == '__main__':
