@@ -3,7 +3,7 @@ import unittest
 
 from explainaboard import FileType, get_processor, Source, TaskType
 from explainaboard.loaders.file_loader import FileLoaderMetadata
-from explainaboard.loaders.loader_registry import get_custom_dataset_loader
+from explainaboard.loaders.loader_registry import get_loader_class
 from explainaboard.metrics.ranking import HitsConfig
 from explainaboard.tests.utils import test_artifacts_path
 
@@ -13,8 +13,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
 
     def test_no_user_defined_features(self):
         dataset = os.path.join(self.artifact_path, "no_custom_feature.json")
-        loader = get_custom_dataset_loader(
-            TaskType.kg_link_tail_prediction,
+        loader = get_loader_class(TaskType.kg_link_tail_prediction)(
             dataset,
             dataset,
             Source.local_filesystem,
@@ -35,5 +34,5 @@ class TestKgLinkTailPrediction(unittest.TestCase):
 
         sys_info = processor.process(metadata, data.samples)
 
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
