@@ -2,7 +2,7 @@ import os
 import unittest
 
 from explainaboard import FileType, get_processor, Source, TaskType
-from explainaboard.loaders.loader_registry import get_custom_dataset_loader
+from explainaboard.loaders.loader_registry import get_loader_class
 from explainaboard.tests.utils import test_artifacts_path
 
 
@@ -12,8 +12,7 @@ class TestQAMultipleChoice(unittest.TestCase):
     json_output = os.path.join(artifact_path, "output.json")
 
     def test_load_json(self):
-        loader = get_custom_dataset_loader(
-            TaskType.qa_multiple_choice,
+        loader = get_loader_class(TaskType.qa_multiple_choice)(
             self.json_dataset,
             self.json_output,
             Source.local_filesystem,
@@ -25,8 +24,7 @@ class TestQAMultipleChoice(unittest.TestCase):
         self.assertEqual(len(data), 4)
 
     def test_generate_system_analysis(self):
-        loader = get_custom_dataset_loader(
-            TaskType.qa_multiple_choice,
+        loader = get_loader_class(TaskType.qa_multiple_choice)(
             self.json_dataset,
             self.json_output,
             Source.local_filesystem,
@@ -44,7 +42,7 @@ class TestQAMultipleChoice(unittest.TestCase):
         processor = get_processor(TaskType.qa_multiple_choice.value)
         sys_info = processor.process(metadata, data)
 
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
 
     def test_multiple_qa_customized_feature(self):
@@ -52,8 +50,7 @@ class TestQAMultipleChoice(unittest.TestCase):
         output_path = os.path.join(
             self.artifact_path, "output_fig_qa_customized_features.json"
         )
-        loader = get_custom_dataset_loader(
-            TaskType.qa_multiple_choice,
+        loader = get_loader_class(TaskType.qa_multiple_choice)(
             dataset_path,
             output_path,
             Source.local_filesystem,
@@ -77,7 +74,7 @@ class TestQAMultipleChoice(unittest.TestCase):
 
         sys_info = processor.process(metadata, data.samples)
 
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
 
 
