@@ -1,11 +1,15 @@
 import os
 import unittest
 
+import numpy as np
+
 from explainaboard import FileType, get_processor, Source, TaskType
-from explainaboard.loaders import get_custom_dataset_loader, get_datalab_loader
+from explainaboard.loaders import get_loader_class
 from explainaboard.loaders.file_loader import DatalabLoaderOption
+from explainaboard.metrics.external_eval import ExternalEvalConfig, ExternalEvalResult
 from explainaboard.tests.utils import OPTIONAL_TEST_SUITES, test_artifacts_path
 from explainaboard.utils import cache_api
+from explainaboard.utils.typing_utils import narrow
 
 
 class TestSummarization(unittest.TestCase):
@@ -14,8 +18,7 @@ class TestSummarization(unittest.TestCase):
     txt_output = os.path.join(artifact_path, "output.txt")
 
     def test_load_tsv(self):
-        loader = get_custom_dataset_loader(
-            TaskType.summarization,
+        loader = get_loader_class(TaskType.summarization)(
             self.tsv_dataset,
             self.txt_output,
             Source.local_filesystem,
@@ -31,8 +34,7 @@ class TestSummarization(unittest.TestCase):
         self.assertTrue(sample["hypothesis"].startswith("washington"))
 
     def test_generate_system_analysis(self):
-        loader = get_custom_dataset_loader(
-            TaskType.summarization,
+        loader = get_loader_class(TaskType.summarization)(
             self.tsv_dataset,
             self.txt_output,
             Source.local_filesystem,
@@ -40,7 +42,7 @@ class TestSummarization(unittest.TestCase):
             FileType.tsv,
             FileType.text,
         )
-        data = loader.load()
+        data = loader.load().samples
 
         metadata = {
             "task_name": TaskType.summarization.value,
@@ -52,8 +54,7 @@ class TestSummarization(unittest.TestCase):
 
         sys_info = processor.process(metadata, data)
 
-        # analysis.write_to_directory("./")
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
 
     def test_default_features_dont_modify_condgen(self):
@@ -61,14 +62,17 @@ class TestSummarization(unittest.TestCase):
         condgen_processor = get_processor(TaskType.conditional_generation.value)
         sum_processor = get_processor(TaskType.summarization.value)
 
-        condgen_features_1 = condgen_processor.default_features()
-        sum_features = sum_processor.default_features()
-        condgen_features_2 = condgen_processor.default_features()
+        condgen_features_1 = condgen_processor.default_analysis_levels()
+        sum_features = sum_processor.default_analysis_levels()
+        condgen_features_2 = condgen_processor.default_analysis_levels()
 
-        # MT features didn't change condgen features
-        self.assertDictEqual(condgen_features_1, condgen_features_2)
-        # condgen features are a subset of sum features
-        self.assertDictEqual(sum_features, {**sum_features, **condgen_features_1})
+        for cf1, cf2, sumf in zip(condgen_features_1, condgen_features_2, sum_features):
+            lcf1 = set(cf1.features.keys())
+            lcf2 = set(cf2.features.keys())
+            lsumf = set(sumf.features.keys())
+            self.assertEqual(lcf1, lcf2)
+            # condgen features are a subset of MT features
+            self.assertTrue(all([x in lsumf] for x in lcf1))
 
     # Commented out following code since it's too slow for unittest
     @unittest.skipUnless('test_sum' in OPTIONAL_TEST_SUITES, reason='time consuming')
@@ -79,8 +83,7 @@ class TestSummarization(unittest.TestCase):
             'predictions/summarization/cnndm-bart-output.txt',
         )
 
-        loader = get_datalab_loader(
-            TaskType.summarization,
+        loader = get_loader_class(TaskType.summarization).from_datalab(
             dataset=DatalabLoaderOption("cnn_dailymail", "3.0.0"),
             output_data=json_output_customized,
             output_source=Source.local_filesystem,
@@ -95,11 +98,50 @@ class TestSummarization(unittest.TestCase):
             "metric_names": ["rouge1"],
         }
         processor = get_processor(TaskType.summarization)
-        sys_info = processor.process(metadata, data)
+        sys_info = processor.process(metadata, data.samples)
 
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
 
+    @unittest.skip('Not yet fixed in v0.11')
+    def test_generate_system_human_eval(self):
+        loader = get_loader_class(TaskType.summarization)(
+            self.tsv_dataset,
+            self.txt_output,
+            Source.local_filesystem,
+            Source.local_filesystem,
+            FileType.tsv,
+            FileType.text,
+        )
+        data = loader.load()
 
-if __name__ == '__main__':
-    unittest.main()
+        metadata = {
+            "task_name": TaskType.summarization.value,
+            "dataset_name": "cnndm",
+            "metric_configs": {
+                "example": [
+                    ExternalEvalConfig(
+                        name="LikertScore_fluency",
+                        aspect="fluency",
+                        n_annotators=2,
+                        categories=5,
+                        external_stats=np.array([[2, 2], [1, 1], [3, 3]]),
+                    )
+                ]
+            },
+        }
+
+        processor = get_processor(TaskType.summarization.value)
+
+        sys_info = processor.process(metadata, data.samples)
+        # print(sys_info.results.overall)
+        # print(metadata["metric_configs"][0])
+        self.assertIsNotNone(sys_info.results.analyses)
+        fluency = [
+            x
+            for x in sys_info.results.overall[0]
+            if x.metric_name == "LikertScore_fluency"
+        ][0]
+        self.assertEqual(fluency.value, 2.0)
+        human_performance = narrow(ExternalEvalResult, fluency.auxiliary_result)
+        self.assertEqual(human_performance.agreement, 1.0)
