@@ -2,7 +2,7 @@ import os
 import unittest
 
 from explainaboard import FileType, get_processor, Source, TaskType
-from explainaboard.loaders.loader_registry import get_custom_dataset_loader
+from explainaboard.loaders.loader_registry import get_loader_class
 from explainaboard.tests.utils import test_artifacts_path
 
 
@@ -12,8 +12,7 @@ class TestWordSegmentation(unittest.TestCase):
     conll_output = os.path.join(artifact_path, "prediction.tsv")
 
     def test_generate_system_analysis(self):
-        loader = get_custom_dataset_loader(
-            TaskType.word_segmentation,
+        loader = get_loader_class(TaskType.word_segmentation)(
             self.conll_dataset,
             self.conll_output,
             Source.local_filesystem,
@@ -34,5 +33,5 @@ class TestWordSegmentation(unittest.TestCase):
 
         sys_info = processor.process(metadata, data)
 
-        self.assertIsNotNone(sys_info.results.fine_grained)
+        self.assertIsNotNone(sys_info.results.analyses)
         self.assertGreater(len(sys_info.results.overall), 0)
