@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import functools
 import itertools
-import sys
 
 
 def freeze(d):
@@ -13,10 +12,6 @@ def freeze(d):
     return d
 
 
-def eprint(*args, **kwargs):
-    print(*args, file=sys.stderr, **kwargs)
-
-
 def zip_dict(*dicts):
     """Iterate over items of dictionaries grouped by their keys."""
     for key in set(itertools.chain(*dicts)):  # set merge all keys
